@@ -21,7 +21,8 @@ cp -fv grc.1 $MANDIR/man1
 cp -fv grcat.1 $MANDIR/man1
 mkdir -p $CONFDIR
 cp -fv grc.conf $CONFDIR
+cp -fv grc.zsh $CONFDIR
+cp -fv grc.fish $CONFDIR
 mkdir -p $PROFILEDIR
 cp -fv grc.bashrc $PROFILEDIR
 
-
